@@ -23,7 +23,10 @@ use exitfailure::ExitFailure;
 fn main() -> Result<(), ExitFailure> {
     let opt = Opt::from_args();
 
-    let response = match opt {
+    #[cfg(windows)]
+    let _ = colored::control::set_virtual_terminal(true);
+
+    match opt {
         Opt::TLE {
             target_file,
             gen_file,
@@ -110,7 +113,5 @@ fn main() -> Result<(), ExitFailure> {
             run_rte,
         ),
         Opt::Example { cmp, tle, check } => subcommand::cmd_example::run(cmp, tle, check),
-    };
-
-    response
+    }
 }
