@@ -10,6 +10,8 @@ pub trait Language {
     fn build(&self) -> bool;
     fn execute(&self, timeout: u32, testcase: u32) -> StatusResponse;
     fn set_stdio(&mut self, stdin: &str);
+    fn is_installed(&self) -> bool;
+    fn get_name(&self) -> String;
 }
 
 pub struct StatusResponse {
@@ -52,3 +54,23 @@ pub fn is_compiled_error(status: &CPStatus) -> bool {
 pub fn is_runtime_error(status: &CPStatus) -> bool {
     *status == CPStatus::RTE
 }
+
+// Extension
+#[derive(PartialEq)]
+pub enum Extension {
+    Cpp,
+    Python,
+    NotExtensionSupported
+}
+
+pub fn map_extension(ext: &str) -> Extension {
+    match ext {
+        "h"|"hh"|"hpp"|"hxx"|"h++"|"cc"|"cpp"|"cxx"|"c++" => Extension::Cpp,
+        "py" => Extension::Python,
+        _ => Extension::NotExtensionSupported
+    }
+}
+
+pub fn is_extension_supported(ext: &str) -> bool {
+    map_extension(&ext) != Extension::NotExtensionSupported
+}
\ No newline at end of file
