@@ -16,10 +16,7 @@ use crate::error::handle_error::{
     throw_break_found_msg, throw_compiler_error_msg, throw_runtime_error_msg,
     throw_time_limit_exceeded_msg,
 };
-use crate::file_handler::file::{
-    copy_file, create_folder_or_error, file_exists_or_error, format_filename_test_case,
-    load_testcases, remove_files, remove_folder, save_test_case,
-};
+use crate::file_handler::file::{can_run_language_or_error, copy_file, create_folder_or_error, file_exists_or_error, format_filename_test_case, is_extension_supported_or_error, load_testcases, remove_files, remove_folder, save_test_case};
 use crate::file_handler::path::get_root_path;
 use crate::generator::generator::execute_generator;
 use crate::painter::style::{
@@ -64,6 +61,15 @@ pub fn run(
     // verify that the generator file exists
     file_exists_or_error(gen_file.to_str().unwrap(), "<gen-file>")?;
 
+    // verify that the target file extension is supported
+    is_extension_supported_or_error(target_file.to_str().unwrap())?;
+
+    // verify that the correct file extension is supported
+    is_extension_supported_or_error(correct_file.to_str().unwrap())?;
+
+    // verify that the generator file extension is supported
+    is_extension_supported_or_error(gen_file.to_str().unwrap())?;
+
     let root = &get_root_path()[..];
 
     // Get the language depending on the extension of the correct_file
@@ -77,6 +83,9 @@ pub fn run(
     );
     let any_correct: Box<dyn Language> = any_correct.unwrap();
     let correct_file_lang: &dyn Language = any_correct.as_ref();
+    
+    // verify that the program to run the correct file is installed
+    can_run_language_or_error(correct_file_lang)?;
 
     // Get the language depending on the extension of the target_file
     let any_target: Option<Box<dyn Language>> = get_language_by_ext_default(
@@ -89,6 +98,9 @@ pub fn run(
     );
     let any_target: Box<dyn Language> = any_target.unwrap();
     let target_file_lang: &dyn Language = any_target.as_ref();
+    
+    // verify that the program to run the target file is installed
+    can_run_language_or_error(target_file_lang)?;
 
     // Get the language depending on the extension of the gen_file
     let any_gen: Option<Box<dyn Language>> =
@@ -96,6 +108,9 @@ pub fn run(
     let any_gen: Box<dyn Language> = any_gen.unwrap();
     let generator_file_lang: &dyn Language = any_gen.as_ref();
 
+    // verify that the program to run the generator file is installed
+    can_run_language_or_error(generator_file_lang)?;
+
     let can_compile_gen = generator_file_lang.build();
     if !can_compile_gen {
         return throw_compiler_error_msg("generator", "<gen-file>");
